-- Custom votescreen by Indev
-- Cycles between different vote backgrounds (and theme)
-- Only compatible with the Saturn Client :)

-- Themes go there
local themes = {
	{ name = "Vanilla", texture = "VANI" },
	{ name = "Pikmin", texture = "PIKM", vote_music = "PIKMV" },
	{ name = "SuperMarioSunshine", texture = "SMSH", vote_music = "SMSHV" },
	{ name = "MarioKart", texture = "MAKA", vote_music = "MAKAV" },
	{ name = "Lario", texture = "LARI", vote_music = "LARIV" },
	{ name = "Xmas", texture = "XMAS", vote_music = "XMASV" },
	{ name = "Frontiers", texture = "FRON", vote_music = "FRONV" },
	{ name = "SuperMarioKart", texture = "SMKA", vote_music = "SMKAV" },
	{ name = "Funky", texture = "FUNK", vote_music = "FUNKV" },
	{ name = "Hawaii", texture = "HAWA", vote_music = "HAWAV" },
	
}

-- Forward declaration...
local gettheme

-- Netvars
local changetheme = 0
local themenum = 1

local cv_changetheme_interval = CV_RegisterVar {
    name = "votetheme_change_interval",
    defaultvalue = "1",
    possiblevalue = CV_Unsigned,
    flags = CV_NETVAR,
}

local votetheme_prefer_cons_t = {Off = 0}

for i = 1, #themes do
    local name = themes[i].name or "Theme"..i
    votetheme_prefer_cons_t[name] = i
end

local cv_preftheme = CV_RegisterVar {
    name = "votetheme_prefer",
    defaultvalue = "0",
    PossibleValue = votetheme_prefer_cons_t,
    flags = CV_CALL|CV_NOINIT,
    func = function(cv)
        local theme = gettheme()
        
        if theme.texture and hud.setVoteBackground then
            hud.setVoteBackground(theme.texture)
        end
    end,
}

gettheme = function()
    if cv_preftheme.value == 0 then
        return themes[themenum]
    end
    
    return themes[cv_preftheme.value]
end

addHook("IntermissionThinker", function()
    if changetheme == 0 then
        changetheme = cv_changetheme_interval.value
        
        themenum = themenum+1
        
        if themenum > #themes then
            themenum = 1
        end
        
        local theme = gettheme()
        
        if theme.texture and hud.setVoteBackground then
            hud.setVoteBackground(theme.texture)
        end
    end
end)

addHook("MusicChange", function(_, musname)
    -- :Trollic:
    if not hud.setVoteBackground then return end

    local theme = gettheme()
    local musname = musname:lower()
    
    if not (theme and theme.vote_music) then return end
    
    -- Lazy, maybe can do something with string.sub but eh lazy
    if musname == "vote" then
        return theme.vote_music
    elseif musname == "voteea" then
        return theme.vote_music.."a"
    elseif musname == "voteeb" then
        return theme.vote_music.."b"
    end
end)

addHook("MapLoad", function()
    changetheme = max(0, changetheme-1)
end)

addHook("NetVars", function(net)
    changetheme = net(changetheme)
    themenum = net(themenum)
end)